@@ -21,7 +21,7 @@ from .. import logic
 from .. import models
 from ..logic import user_log, object_log, comments, object_sorting
 from ..logic.actions import get_action, get_actions, get_action_type, get_action_types
-from ..logic.action_permissions import get_user_action_permissions
+from ..logic.action_permissions import get_user_action_permissions, get_sorted_actions_for_user
 from ..logic.object_permissions import Permissions, get_user_object_permissions, object_is_public, get_object_permissions_for_users, set_object_public, set_user_object_permissions, set_group_object_permissions, set_project_object_permissions, get_objects_with_permissions, get_object_info_with_permissions, get_object_permissions_for_groups, get_object_permissions_for_projects, request_object_permissions
 from ..logic.datatypes import JSONEncoder
 from ..logic.users import get_user, get_users, get_users_by_name
@@ -1211,7 +1211,49 @@ def post_object_comments(object_id):
 @frontend.route('/objects/search/')
 @flask_login.login_required
 def search():
-    return flask.render_template('search.html')
+    actions = get_sorted_actions_for_user(
+        user_id=flask_login.current_user.id
+    )
+    action_types = get_action_types()
+    search_paths = {}
+    search_paths_by_action = {}
+    search_paths_by_action_type = {}
+    for action_type in action_types:
+        search_paths_by_action_type[action_type.id] = {}
+    for action in actions:
+        search_paths_by_action[action.id] = {}
+        if action.type_id not in search_paths_by_action_type:
+            search_paths_by_action_type[action.type_id] = {}
+        for property_path, property_type in logic.schemas.utils.get_property_paths_for_schema(
+                schema=action.schema,
+                valid_property_types={'text', 'bool', 'quantity', 'datetime'}
+        ).items():
+            property_path = '.'.join(
+                key if key is not None else '?'
+                for key in property_path
+            )
+            search_paths_by_action[action.id][property_path] = [property_type]
+            if property_path not in search_paths_by_action_type[action.type_id]:
+                search_paths_by_action_type[action.type_id][property_path] = [property_type]
+            elif property_type not in search_paths_by_action_type[action.type_id][property_path]:
+                search_paths_by_action_type[action.type_id][property_path].append(property_type)
+            if property_path not in search_paths:
+                search_paths[property_path] = [property_type]
+            elif property_type not in search_paths[property_path]:
+                search_paths[property_path].append(property_type)
+    return flask.render_template(
+        'search.html',
+        search_paths=search_paths,
+        search_paths_by_action=search_paths_by_action,
+        search_paths_by_action_type=search_paths_by_action_type,
+        actions=actions,
+        action_types=action_types,
+        datetime=datetime
+    ), 200, {
+        'Cache-Control': 'no-cache, no-store, must-revalidate',
+        'Pragma': 'no-cache',
+        'Expires': '0'
+    }
 
 
 @frontend.route('/objects/referencable')
