@@ -62,6 +62,8 @@ def validate_schema(schema: dict, path: typing.Optional[typing.List[str]] = None
         return _validate_hazards_schema(schema, path)
     elif schema['type'] == 'user':
         return _validate_user_schema(schema, path)
+    elif schema['type'] == 'plotly_chart':
+        return _validate_plotly_chart_schema(schema, path)
     else:
         raise ValidationError('invalid type', path)
 
@@ -544,3 +546,18 @@ def _validate_user_schema(schema: dict, path: typing.List[str]) -> None:
         raise ValidationError('dataverse_export must be True or False', path)
     if 'default' in schema and schema['default'] != 'self':
         raise ValidationError('default must be "self"', path)
+
+
+def _validate_plotly_chart_schema(schema: dict, path: typing.List[str]) -> None:
+    """
+    Validates the given plotly_chart object schema and raises a ValidationError if it is invalid.
+
+    :param schema: the sampledb object schema
+    :param path: the path to this subschema
+    :raise ValidationError: if the schema is invalid.
+    """
+    valid_keys = {'type', 'title', 'note', 'dataverse_export'}
+    schema_keys = schema.keys()
+    invalid_keys = schema_keys - valid_keys
+    if invalid_keys:
+        raise ValidationError('unexpected keys in schema: {}'.format(invalid_keys), path)
