@@ -14,6 +14,7 @@ from . import export_action_schema
 from . import create_other_user
 from . import send_announcement
 from . import set_administrator
+from . import set_up_demo
 from . import set_user_readonly
 from . import set_user_hidden
 from . import run
@@ -32,6 +33,7 @@ script_modules = {
         create_other_user,
         send_announcement,
         set_administrator,
+        set_up_demo,
         set_user_readonly,
         set_user_hidden,
         run
